You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by sl...@apache.org on 2012/04/26 16:35:09 UTC

[2/3] git commit: Fix bug with super columns where row cache is not updated

Fix bug with super columns where row cache is not updated

patch by slebresne; reviewed by jbellis for CASSANDRA-4190


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/eb9f9614
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/eb9f9614
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/eb9f9614

Branch: refs/heads/cassandra-1.1
Commit: eb9f96146efb2611ce75739ecf5e2c2607650d7b
Parents: cb67c98
Author: Sylvain Lebresne <sy...@datastax.com>
Authored: Thu Apr 26 16:32:06 2012 +0200
Committer: Sylvain Lebresne <sy...@datastax.com>
Committed: Thu Apr 26 16:32:06 2012 +0200

----------------------------------------------------------------------
 CHANGES.txt                                        |    1 +
 src/java/org/apache/cassandra/db/ColumnFamily.java |    4 ++--
 2 files changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/eb9f9614/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index 544d393..5b58681 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -9,6 +9,7 @@
  * (CLI) properly handle quotes in create/update keyspace commands (CASSANDRA-4129)
  * Avoids possible deadlock during bootstrap (CASSANDRA-4159)
  * fix stress tool that hangs forever on timeout or error (CASSANDRA-4128)
+ * Fix super columns bug where cache is not updated (CASSANDRA-4190)
 
 
 1.0.9

http://git-wip-us.apache.org/repos/asf/cassandra/blob/eb9f9614/src/java/org/apache/cassandra/db/ColumnFamily.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/db/ColumnFamily.java b/src/java/org/apache/cassandra/db/ColumnFamily.java
index d27a963..0b1e399 100644
--- a/src/java/org/apache/cassandra/db/ColumnFamily.java
+++ b/src/java/org/apache/cassandra/db/ColumnFamily.java
@@ -141,7 +141,7 @@ public class ColumnFamily extends AbstractColumnContainer
     }
 
     /**
      * Same as addAll() but do a cloneMeShallow of SuperColumn if necessary to
      * avoid keeping references to the structure (see #3957).
      */
     public void addAllWithSCCopy(ColumnFamily cf, Allocator allocator)
@@ -150,7 +150,7 @@ public class ColumnFamily extends AbstractColumnContainer
         {
             for (IColumn c : cf)
             {
-                columns.addColumn(((SuperColumn)c).cloneMeShallow(), allocator);
+                columns.addColumn(((SuperColumn)c).cloneMe(), allocator);
             }
             delete(cf);
         }
@@ -141,7 +141,7 @@ public class ColumnFamily extends AbstractColumnContainer
 
     /**
-     * Same as addAll() but do a cloneMeShallow of SuperColumn if necessary to
+     * Same as addAll() but do a cloneMe of SuperColumn if necessary to
      * avoid keeping references to the structure (see #3957).
      */